[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [30449] branches/render25: Render Branch: svn merge https://svn.blender.org/svnroot/bf-blender/trunk/blender -r30435 :30448

Brecht Van Lommel brecht at blender.org
Sat Jul 17 23:11:04 CEST 2010


Revision: 30449
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=30449
Author:   blendix
Date:     2010-07-17 23:11:04 +0200 (Sat, 17 Jul 2010)

Log Message:
-----------
Render Branch: svn merge https://svn.blender.org/svnroot/bf-blender/trunk/blender -r30435:30448

Modified Paths:
--------------
    branches/render25/extern/bullet2/src/BulletDynamics/ConstraintSolver/btConeTwistConstraint.cpp
    branches/render25/release/scripts/io/export_3ds.py
    branches/render25/release/scripts/io/export_fbx.py
    branches/render25/release/scripts/io/export_obj.py
    branches/render25/release/scripts/io/netrender/master_html.py
    branches/render25/release/scripts/io/netrender/repath.py
    branches/render25/release/scripts/io/netrender/slave.py
    branches/render25/release/scripts/io/netrender/utils.py
    branches/render25/release/scripts/modules/bpy/utils.py
    branches/render25/release/scripts/op/uvcalc_smart_project.py
    branches/render25/release/scripts/presets/interaction/maya.py
    branches/render25/release/scripts/ui/space_userpref.py
    branches/render25/source/blender/blenkernel/BKE_library.h
    branches/render25/source/blender/blenkernel/BKE_object.h
    branches/render25/source/blender/blenkernel/intern/curve.c
    branches/render25/source/blender/blenkernel/intern/library.c
    branches/render25/source/blender/blenkernel/intern/object.c
    branches/render25/source/blender/blenkernel/intern/particle_system.c
    branches/render25/source/blender/blenlib/intern/fileops.c
    branches/render25/source/blender/blenlib/intern/math_color.c
    branches/render25/source/blender/blenlib/intern/path_util.c
    branches/render25/source/blender/blenloader/intern/readfile.c
    branches/render25/source/blender/editors/animation/anim_channels_edit.c
    branches/render25/source/blender/editors/animation/anim_markers.c
    branches/render25/source/blender/editors/armature/armature_ops.c
    branches/render25/source/blender/editors/curve/curve_ops.c
    branches/render25/source/blender/editors/mesh/editmesh_mods.c
    branches/render25/source/blender/editors/mesh/mesh_ops.c
    branches/render25/source/blender/editors/metaball/mball_ops.c
    branches/render25/source/blender/editors/object/object_ops.c
    branches/render25/source/blender/editors/physics/physics_ops.c
    branches/render25/source/blender/editors/sculpt_paint/paint_image.c
    branches/render25/source/blender/editors/space_action/action_ops.c
    branches/render25/source/blender/editors/space_file/space_file.c
    branches/render25/source/blender/editors/space_graph/graph_ops.c
    branches/render25/source/blender/editors/space_nla/nla_ops.c
    branches/render25/source/blender/editors/space_node/node_ops.c
    branches/render25/source/blender/editors/space_sequencer/sequencer_draw.c
    branches/render25/source/blender/editors/space_sequencer/sequencer_ops.c
    branches/render25/source/blender/editors/space_view3d/drawobject.c
    branches/render25/source/blender/editors/space_view3d/view3d_view.c
    branches/render25/source/blender/editors/transform/transform_conversions.c
    branches/render25/source/blender/imbuf/intern/imageprocess.c
    branches/render25/source/blender/makesdna/DNA_object_types.h
    branches/render25/source/blender/makesdna/intern/dna_genfile.c
    branches/render25/source/blender/makesrna/intern/rna_action.c
    branches/render25/source/blender/makesrna/intern/rna_controller.c
    branches/render25/source/blender/makesrna/intern/rna_curve.c
    branches/render25/source/blender/makesrna/intern/rna_object.c
    branches/render25/source/blender/makesrna/rna_cleanup/rna_cleaner.py
    branches/render25/source/blender/modifiers/intern/MOD_screw.c
    branches/render25/source/blender/python/generic/bpy_internal_import.c
    branches/render25/source/blender/python/generic/geometry.c
    branches/render25/source/blender/python/generic/mathutils.c
    branches/render25/source/blender/python/generic/mathutils_vector.c
    branches/render25/source/blender/python/intern/bpy_rna.c
    branches/render25/source/blender/render/intern/source/pipeline.c
    branches/render25/source/blender/windowmanager/intern/wm_event_system.c
    branches/render25/source/gameengine/Expressions/PyObjectPlus.cpp
    branches/render25/source/gameengine/GameLogic/SCA_PythonController.cpp
    branches/render25/source/gameengine/Ketsji/KX_PythonSeq.cpp
    branches/render25/source/gameengine/Physics/Bullet/CcdPhysicsController.cpp

Modified: branches/render25/extern/bullet2/src/BulletDynamics/ConstraintSolver/btConeTwistConstraint.cpp
===================================================================
--- branches/render25/extern/bullet2/src/BulletDynamics/ConstraintSolver/btConeTwistConstraint.cpp	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/extern/bullet2/src/BulletDynamics/ConstraintSolver/btConeTwistConstraint.cpp	2010-07-17 21:11:04 UTC (rev 30449)
@@ -601,7 +601,7 @@
 	m_solveSwingLimit = false;
 	// compute rotation of A wrt B (in constraint space)
 	if (m_bMotorEnabled && (!m_useSolveConstraintObsolete))
-	{	// it is assumed that setMotorTarget() was alredy called 
+	{	// it is assumed that setMotorTarget() was already called 
 		// and motor target m_qTarget is within constraint limits
 		// TODO : split rotation to pure swing and pure twist
 		// compute desired transforms in world

Modified: branches/render25/release/scripts/io/export_3ds.py
===================================================================
--- branches/render25/release/scripts/io/export_3ds.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/export_3ds.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -1006,7 +1006,7 @@
                             mat = mat_ls[mat_index]
                             if mat:	mat_name = mat.name
                             else:	mat_name = None
-                        # else there alredy set to none
+                        # else there already set to none
 
                         img = uf.image
 # 						img = f.image

Modified: branches/render25/release/scripts/io/export_fbx.py
===================================================================
--- branches/render25/release/scripts/io/export_fbx.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/export_fbx.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -83,7 +83,7 @@
         if Blender.sys.exists(image_path):
             # Make a name for the target path.
             dest_image_path = dest_dir + image_path.split('\\')[-1].split('/')[-1]
-            if not Blender.sys.exists(dest_image_path): # Image isnt alredy there
+            if not Blender.sys.exists(dest_image_path): # Image isnt already there
                 print('\tCopying "%s" > "%s"' % (image_path, dest_image_path))
                 try:
                     copy_file(image_path, dest_image_path)
@@ -359,7 +359,7 @@
 
             if BATCH_OWN_DIR:
                 new_fbxpath = fbxpath + newname + os.sep
-                # path may alredy exist
+                # path may already exist
                 # TODO - might exist but be a file. unlikely but should probably account for it.
 
                 if bpy.utils.exists(new_fbxpath) == 0:
@@ -391,7 +391,7 @@
 
 
             # Call self with modified args
-            # Dont pass batch options since we alredy usedt them
+            # Dont pass batch options since we already usedt them
             write(filename, data.objects,
                 context,
                 False,
@@ -2763,7 +2763,7 @@
                 act_end =	end
             else:
                 # use existing name
-                if blenAction == blenActionDefault: # have we alredy got the name
+                if blenAction == blenActionDefault: # have we already got the name
                     file.write('\n\tTake: "%s" {' % sane_name_mapping_take[blenAction.name])
                 else:
                     file.write('\n\tTake: "%s" {' % sane_takename(blenAction))
@@ -2918,7 +2918,7 @@
                                         for val, frame in context_bone_anim_keys:
                                             if frame != context_bone_anim_keys[0][1]: # not the first
                                                 file.write(',')
-                                            # frame is alredy one less then blenders frame
+                                            # frame is already one less then blenders frame
                                             file.write('\n\t\t\t\t\t\t\t%i,%.15f,L'  % (fbx_time(frame), val ))
 
                                 if		i==0:	file.write('\n\t\t\t\t\t\tColor: 1,0,0')

Modified: branches/render25/release/scripts/io/export_obj.py
===================================================================
--- branches/render25/release/scripts/io/netrender/master_html.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/netrender/master_html.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -27,9 +27,10 @@
     def output(text):
         handler.wfile.write(bytes(text, encoding='utf8'))
 
-    def head(title):
+    def head(title, refresh = False):
         output("<html><head>")
-        output("<meta http-equiv='refresh' content=5>")
+        if refresh:
+            output("<meta http-equiv='refresh' content=5>")
         output("<script src='/html/netrender.js' type='text/javascript'></script>")
 #		output("<script src='/html/json2.js' type='text/javascript'></script>")
         output("<title>")
@@ -104,7 +105,7 @@
         f.close()
     elif handler.path == "/html" or handler.path == "/":
         handler.send_head(content = "text/html")
-        head("NetRender")
+        head("NetRender", refresh = True)
 
         output("<h2>Jobs</h2>")
 

Modified: branches/render25/release/scripts/io/netrender/repath.py
===================================================================
--- branches/render25/release/scripts/io/netrender/repath.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/netrender/repath.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -83,14 +83,17 @@
         elif paths[i].endswith(".bobj.gz"):
             path_map[os.path.split(paths[i])[0]] = os.path.split(paths[i+1])[0]
         else:
-            path_map[paths[i]] = paths[i+1]
+            path_map[os.path.split(paths[i])[1]] = paths[i+1]
+            
+    # TODO original paths aren't really the orignal path (they are the normalized path
+    # so we repath using the filenames only. 
     
     ###########################
     # LIBRARIES
     ###########################
     for lib in bpy.data.libraries:
         file_path = bpy.utils.expandpath(lib.filepath)
-        new_path = path_map.get(file_path, None)
+        new_path = path_map.get(os.path.split(file_path)[1], None)
         if new_path:
             lib.filepath = new_path
 
@@ -100,7 +103,7 @@
     for image in bpy.data.images:
         if image.source == "FILE" and not image.packed_file:
             file_path = bpy.utils.expandpath(image.filepath)
-            new_path = path_map.get(file_path, None)
+            new_path = path_map.get(os.path.split(file_path)[1], None)
             if new_path:
                 image.filepath = new_path
             

Modified: branches/render25/release/scripts/io/netrender/slave.py
===================================================================
--- branches/render25/release/scripts/io/netrender/slave.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/netrender/slave.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -79,6 +79,8 @@
             job_full_path = prefixPath(JOB_PREFIX, rfile.filepath, main_path, force = True)
 
     if not found:
+        # Force prefix path if not found
+        job_full_path = prefixPath(JOB_PREFIX, rfile.filepath, main_path, force = True)
         temp_path = JOB_PREFIX + "slave.temp"
         conn.request("GET", fileURL(job_id, rfile.index), headers={"slave-id":slave_id})
         response = conn.getresponse()

Modified: branches/render25/release/scripts/io/netrender/utils.py
===================================================================
--- branches/render25/release/scripts/io/netrender/utils.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/netrender/utils.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -171,7 +171,7 @@
         # if an absolute path, make sure path exists, if it doesn't, use relative local path
         full_path = file_path
         if force or not os.path.exists(full_path):
-            p, n = os.path.split(full_path)
+            p, n = os.path.split(os.path.normpath(full_path))
 
             if prefix_path and p.startswith(prefix_path):
                 if len(prefix_path) < len(p):

Modified: branches/render25/release/scripts/modules/bpy/utils.py
===================================================================
--- branches/render25/release/scripts/modules/bpy/utils.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/modules/bpy/utils.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -60,7 +60,7 @@
 
     :arg path: this path is scanned for scripts and packages.
     :type path: string
-    :arg loaded_modules: alredy loaded module names, files matching these names will be ignored.

@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list
--- branches/render25/release/scripts/io/export_obj.py	2010-07-17 21:01:00 UTC (rev 30448)
+++ branches/render25/release/scripts/io/export_obj.py	2010-07-17 21:11:04 UTC (rev 30449)
@@ -193,7 +193,7 @@
 # 		if bpy.sys.exists(image_path):
 # 			# Make a name for the target path.
 # 			dest_image_path = dest_dir + image_path.split('\\')[-1].split('/')[-1]
-# 			if not bpy.utils.exists(dest_image_path): # Image isnt alredy there
+# 			if not bpy.utils.exists(dest_image_path): # Image isnt already there
 # 				print('\tCopying "%s" > "%s"' % (image_path, dest_image_path))
 # 				copy_file(image_path, dest_image_path)
 # 				copyCount+=1
@@ -299,7 +299,7 @@
           EXPORT_POLYGROUPS=False,
           EXPORT_CURVE_AS_NURBS=True):
     '''
-    Basic write function. The context and options must be alredy set
+    Basic write function. The context and options must be already set
     This can be accessed externaly
     eg.
     write( 'c:\\test\\foobar.obj', Blender.Object.GetSelected() ) # Using default options.
@@ -681,7 +681,7 @@
 
                 # CHECK FOR CONTEXT SWITCH
                 if key == contextMat:
-                    pass # Context alredy switched, dont do anything
+                    pass # Context already switched, dont do anything
                 else:
                     if key[0] == None and key[1] == None:
                         # Write a null material, since we know the context has changed.

Modified: branches/render25/release/scripts/io/netrender/master_html.py
===================================================================